
Summary:       The BOINC client
Name:          boinc-client
Version:       7.20.2
Release:       2%{?dist}
License:       LGPLv2+
URL:           http://boinc.berkeley.edu/

%global major_version %(v=%{version}; echo ${v:0:4})
%global commit 5222682feca5506f6168ed5883581a0320c13f8b
%global gittag client_release/%{major_version}/%{version}
%global gittag_custom client_release-%{major_version}-%{version}
%global shortcommit %(c=%{commit}; echo ${c:0:7})


Source0:       https://github.com/BOINC/boinc/archive/%{gittag}/%{name}-%{version}.tar.gz
SOURCE1:       boinc-client-logrotate-d
SOURCE3:       36x11-common_xhost-boinc
SOURCE4:       config.properties
SOURCE5:       edu.berkeley.BOINC.metainfo.xml

Patch2:        disable_idle_time_detection.patch
Patch3:        manager_close_no_service_stop.patch
Patch4:        manager_exit_menu_entry_removal.patch
Patch5:        manager_shut_down_connected_client.patch
Patch6:        prevent_manager_from_starting_client.patch

Patch8:	       boinc-client-c99.patch

Requires:         logrotate
Requires(post):   systemd
Requires(preun):  systemd
Requires(postun): systemd
Requires(pre):    shadow-utils

BuildRequires: curl-devel
BuildRequires: freeglut-devel
BuildRequires: gcc-c++
BuildRequires: gettext
BuildRequires: gtk3-devel
BuildRequires: docbook2X
BuildRequires: libXmu-devel
BuildRequires: pkgconfig(libjpeg)
BuildRequires: pkgconfig(libnotify)
BuildRequires: libtool
BuildRequires: libXScrnSaver-devel
BuildRequires: mesa-libGLU-devel
BuildRequires: pkgconfig(openssl)
BuildRequires: sqlite-devel
BuildRequires: systemd-rpm-macros
BuildRequires: wxGTK-devel
BuildRequires: pkgconfig(xcb-util)
BuildRequires: pkgconfig(libunwind)
BuildRequires: make


%description 
The Berkeley Open Infrastructure for Network Computing (BOINC) is an open-
source software platform which supports distributed computing, primarily in
the form of "volunteer" computing and "desktop Grid" computing.  It is well
suited for problems which are often described as "trivially parallel".  BOINC
is the underlying software used by projects such as SETI@home, Einstein@Home,
ClimatePrediciton.net, the World Community Grid, and many other distributed
computing projects.

This package installs the BOINC client software, which will allow your
computer to participate in one or more BOINC projects, using your spare
computer time to search for cures for diseases, model protein folding, study
global warming, discover sources of gravitational waves, and many other types
of scientific and mathematical research.

%package -n boinc-manager
Summary:    GUI to control and monitor %{name}
Requires:   hicolor-icon-theme
Requires:   %{name} = %{version}-%{release}

%description -n boinc-manager
The BOINC Manager is a graphical monitor and control utility for the BOINC
core client. It gives a detailed overview of the state of the client it is
monitoring. The BOINC Manager has two modes of operation, the "Simple View" in
which it only displays the most important information and the "Advanced View"
in which all information and all control elements are available.

%package devel
Summary:    Development files for %{name}
Requires:   %{name} = %{version}-%{release}
Requires:   openssl-devel
Requires:   mariadb-connector-c-devel

%description devel
This package contains development files for %{name}.

%package static
Summary:    Static libraries for %{name}
Requires:   %{name}-devel = %{version}-%{release}

%description static
This package contains static libraries for %{name}.

%package doc
Summary:    Documentation files for %{name}
BuildArch:  noarch
Requires:   %{name} = %{version}-%{release}

%description doc
This package contains documentation files for %{name}.

%prep
%autosetup -p1 -n boinc-%{gittag_custom}

for file in $(ls | grep checkin_notes_20); do
    iconv -f ISO-8859-1 -t UTF-8 -o ${file}.utf8 ${file}
    mv ${file}.utf8 ${file}
done

for file in $(ls clientgui | grep .cpp$ ) $(ls clientgui | grep .h$ ); do 
    chmod 644 clientgui/${file}
done

%build

%ifarch %{ix86}
%global boinc_platform i686-pc-linux-gnu
%endif
%ifarch powerpc ppc
%global boinc_platform powerpc-linux-gnu
%endif
%ifarch powerpc64 ppc64
%global boinc_platform ppc64-linux-gnu
%endif
%ifarch aarch64
%global boinc_platform aarch64-unknown-linux-gnu
%endif

%if %{defined boinc_platform}
%global confflags --with-boinc-platform=%{boinc_platform}
%endif

./_autosetup

%configure %{?confflags} \
  --disable-silent-rules \
  --enable-dynamic-client-linkage \
  --disable-server \
  --disable-fcgi \
  --enable-unicode \
  --with-wx-config=/usr/bin/wx-config-3.2 \
  --with-ssl \
  --with-x \
  STRIP=: \
  DOCBOOK2X_MAN=/usr/bin/db2x_docbook2man \
  "CXXFLAGS=$(pkg-config gtk+-x11-3.0 --cflags --libs) ${RPM_OPT_FLAGS} -DNDEBUG"

sed -i 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' libtool
sed -i 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' libtool

make %{?_smp_mflags}

%install
mkdir -p %{buildroot}%{_datadir}/icons/hicolor/16x16/apps
mkdir -p %{buildroot}%{_datadir}/icons/hicolor/32x32/apps
mkdir -p %{buildroot}%{_datadir}/icons/hicolor/48x48/apps
mkdir -p %{buildroot}%{_metainfodir}
mkdir -p %{buildroot}%{_unitdir}
mkdir -p %{buildroot}%{_localstatedir}/lib/boinc
mkdir -p %{buildroot}%{_mandir}/man1
mkdir -p %{buildroot}%{_sysconfdir}/logrotate.d
mkdir -p %{buildroot}%{_sysconfdir}/bash_completion.d
mkdir -p %{buildroot}%{_sysconfdir}/X11/Xsession.d
mkdir -p %{buildroot}%{_sysconfdir}/boinc-client

make install INSTALL="%{__install} -p" DESTDIR=%{buildroot}


rm %{buildroot}%{_libdir}/*.la

rm -f %{buildroot}%{_sysconfdir}/init.d/%{name} %{buildroot}%{_sysconfdir}/sysconfig/%{name}

install -p -m644 %{SOURCE1} %{buildroot}%{_sysconfdir}/logrotate.d/%{name}
install -p -m644 %{SOURCE3} %{buildroot}%{_sysconfdir}/X11/Xsession.d/36x11-common_xhost-boinc
install -p -m644 %{SOURCE4} %{buildroot}%{_sysconfdir}/boinc-client/config.properties

install -p -m644 packages/generic/sea/boincmgr.16x16.png %{buildroot}%{_datadir}/icons/hicolor/16x16/apps/boincmgr.png
install -p -m644 packages/generic/sea/boincmgr.32x32.png %{buildroot}%{_datadir}/icons/hicolor/32x32/apps/boincmgr.png
install -p -m644 packages/generic/sea/boincmgr.48x48.png %{buildroot}%{_datadir}/icons/hicolor/48x48/apps/boincmgr.png

install -p -m644 %{SOURCE5} %{buildroot}%{_metainfodir}/edu.berkeley.BOINC.metainfo.xml

%find_lang BOINC-Manager
%find_lang BOINC-Client

install -p -m644 client/scripts/boinc.bash %{buildroot}%{_sysconfdir}/bash_completion.d/boinc-client

%pre

getent group boinc >/dev/null || groupadd -r boinc
getent passwd boinc >/dev/null || \
useradd -r -g boinc -d %{_localstatedir}/lib/boinc -s /sbin/nologin \
    -c "BOINC client account." boinc
exit 0

%post
%{?ldconfig}
%systemd_post boinc-client.service

%preun
%systemd_preun boinc-client.service

%postun
%{?ldconfig}
%systemd_postun_with_restart boinc-client.service  


%files -f BOINC-Client.lang
%doc COPYING COPYRIGHT
%{_bindir}/boinc
%{_bindir}/boinc_client
%{_bindir}/boinccmd
%{_bindir}/switcher
%{_unitdir}/%{name}.service
%{_mandir}/man1/boinccmd.1.gz
%{_mandir}/man1/boinc.1.gz
%{_libdir}/*.so.*
%config(noreplace) %{_sysconfdir}/logrotate.d/boinc-client
%config(noreplace) %{_sysconfdir}/bash_completion.d/boinc-client
%attr(-,boinc,boinc) %{_localstatedir}/lib/boinc/
%{_sysconfdir}/X11/Xsession.d/36x11-common_xhost-boinc
%{_sysconfdir}/boinc-client/config.properties


%files doc
%doc checkin_notes checkin_notes_*

%files -n boinc-manager -f BOINC-Manager.lang
%{_bindir}/boincmgr
%{_bindir}/boincscr
%{_datadir}/applications/boinc.desktop
%{_metainfodir}/edu.berkeley.BOINC.metainfo.xml
%{_datadir}/boinc-manager/skins/*
%{_datadir}/icons/hicolor/16x16/apps/boincmgr.png
%{_datadir}/icons/hicolor/32x32/apps/boincmgr.png
%{_datadir}/icons/hicolor/48x48/apps/boincmgr.png
%{_datadir}/icons/hicolor/64x64/apps/boinc.png
%{_datadir}/icons/hicolor/scalable/apps/boinc.svg
%{_mandir}/man1/boincmgr.1.gz

%files static
%{_libdir}/libboinc.a
%{_libdir}/libboinc_api.a
%{_libdir}/libboinc_crypt.a
%{_libdir}/libboinc_graphics2.a
%{_libdir}/libboinc_opencl.a

%files devel
%{_libdir}/*.so
%{_includedir}/boinc
%{_libdir}/pkgconfig/libboinc.pc
%{_libdir}/pkgconfig/libboinc_api.pc
%{_libdir}/pkgconfig/libboinc_crypt.pc
%{_libdir}/pkgconfig/libboinc_graphics2.pc
%{_libdir}/pkgconfig/libboinc_opencl.pc

%changelog
* Wed Apr 24 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 7.20.2-2
- rebase to add ocs and ts macros

* Thu Apr 11 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 7.20.2-1
- initial build
